@@ -1,11 +1,11 @@
-use crate::entries::{game::GameEntry, game_move::GameMoveEntry};
+use crate::{entries::game::GameEntry, prelude::MoveInfo};
 use hdk::prelude::*;
 use holo_hash::EntryHashB64;
 
 #[derive(Serialize, Deserialize, Debug, SerializedBytes)]
 pub enum SignalPayload {
     GameStarted((EntryHashB64, GameEntry)),
-    Move(GameMoveEntry),
+    Move(MoveInfo),
 }
 
 /**
@@ -17,6 +17,7 @@ pub fn send_signal_to_players(game: GameEntry, signal: SignalPayload) -> ExternR
     let opponents: Vec<AgentPubKey> = game
         .players
         .into_iter()
+        .map(|p| AgentPubKey::from(p))
         .filter(|player| player.clone() != agent_info.agent_latest_pubkey.clone())
         .collect();
 
